==> order-center-api-3.0.0-CLOUD-TEST-20221206.114917-179-sources.jar: com/tydic/dyc/oc/service/saleorder/bo/UocCreateSaleProcInsUpdateStatusDomainServiceReqTaskBo.java <==
package com.tydic.dyc.oc.service.saleorder.bo;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.List;

/**
 * 标题:UocCreateSaleProcInsUpdateStatusDomainServiceReqTaskBo
 * 说明:
 * 时间:2022/2/24 19:17
 * 作者:田桂银
 */
@Data
public class UocCreateSaleProcInsUpdateStatusDomainServiceReqTaskBo implements Serializable {

    private static final long serialVersionUID = 1982879950619265400L;

    /**
     * 流程实例ID
     */
    private String procInstId;
    /**
     * 任务Id
     */
    private String taskId;
    /**
     * 环节编码
     */
    private String stepId;
    /**
     * 处理人
     */
    private String assignee;
    /**
     * 候选人列表
     */
    private List<UocCandidatesBO> candidates;
    /**
     * 表单
     */
    private String formUrl;
    /**
     * 流程定义ID
     */
    private String procDefId;
    /**
     * 流程定义Key
     */
    private String procDefKey;
    /**
     * 流程名称
     */
    private String procDefName;
    /**
     * 业务对象ID
     */
    private Long busiObjId;
    /**
     * 业务对象类型
     */
    private Integer busiObjType;
    /**
     * 是否完成
     */
    private Boolean finish;
    /**
     * 审批环节编码
     */
    private String auditStepId;
    /**
     * 审批环节是否结束
     */
    private Boolean auditStepFinish;
    /**
     * 0 ：环节任务   1：前加签任务  2：后加签任务  3：存在后加签任务
     */
    private Integer taskSignTag = 0;

    /**
     * 处理结果
     */
    private Integer dealResult;

    /**
     * 处理备注
     */
    private String dealRemark;

}

==> order-center-api-3.3.0-CLOUD-TEST-20241225.071155-1-sources.jar: com/tydic/dyc/oc/service/saleorder/bo/UocCreateSaleProcInsUpdateStatusDomainServiceReqTaskBo.java <==
package com.tydic.dyc.oc.service.saleorder.bo;


import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.List;

/**
 * 标题:UocCreateSaleProcInsUpdateStatusDomainServiceReqTaskBo
 * 说明:
 * 时间:2022/2/24 19:17
 * 作者:田桂银
 */
@Data
@EqualsAndHashCode(callSuper=false)
public class UocCreateSaleProcInsUpdateStatusDomainServiceReqTaskBo implements Serializable {

    private static final long serialVersionUID = 1982879950619265400L;

    /**
     * 流程实例ID
     */
    private String procInstId;
    /**
     * 任务Id
     */
    private String taskId;
    /**
     * 环节编码
     */
    private String stepId;
    /**
     * 处理人
     */
    private String assignee;
    /**
     * 候选人列表
     */
    private List<UocCandidatesBO> candidates;
    /**
     * 表单
     */
    private String formUrl;
    /**
     * 流程定义ID
     */
    private String procDefId;
    /**
     * 流程定义Key
     */
    private String procDefKey;
    /**
     * 流程名称
     */
    private String procDefName;
    /**
     * 业务对象ID
     */
    private Long busiObjId;
    /**
     * 业务对象类型
     */
    private Integer busiObjType;
    /**
     * 是否完成
     */
    private Boolean finish;
    /**
     * 审批环节编码
     */
    private String auditStepId;
    /**
     * 审批环节是否结束
     */
    private Boolean auditStepFinish;
    /**
     * 0 ：环节任务   1：前加签任务  2：后加签任务  3：存在后加签任务
     */
    private Integer taskSignTag = 0;

    /**
     * 处理结果
     */
    private Integer dealResult;

    /**
     * 处理备注
     */
    private String dealRemark;

}
